@@ -2,6 +2,7 @@ from copy import deepcopy
 from functools import partial
 from typing import Type, Sequence, Tuple, Dict, List, Optional, Callable, Any
 
+import traceback
 from marshmallow import INCLUDE
 from marshmallow import ValidationError
 from rest_framework.authentication import BaseAuthentication
@@ -289,6 +290,7 @@ class AlchemyJsonApiViewBuilder:
                 try:
                     attributes = self._before_create_callback(request, attributes)
                 except Exception as e:
+                    traceback.print_exc()
                     return {'errors': [str(e)]}, '', getattr(e, 'http_status', HTTP_500_INTERNAL_SERVER_ERROR)
 
             try:
@@ -303,6 +305,7 @@ class AlchemyJsonApiViewBuilder:
                 try:
                     self._after_create_callback(request, attributes, obj)
                 except Exception as e:
+                    traceback.print_exc()
                     return {'errors': [str(e)]}, '', getattr(e, 'http_status', HTTP_500_INTERNAL_SERVER_ERROR)
                 obj.refresh_from_db()
 
@@ -326,6 +329,7 @@ class AlchemyJsonApiViewBuilder:
                 try:
                     attributes = self._before_update_callback(request, attributes, obj)
                 except Exception as e:
+                    traceback.print_exc()
                     return {'errors': [str(e)]}, getattr(e, 'http_status', HTTP_500_INTERNAL_SERVER_ERROR)
                 obj.refresh_from_db()
 
@@ -338,6 +342,7 @@ class AlchemyJsonApiViewBuilder:
                 try:
                     self._after_update_callback(request, obj)
                 except Exception as e:
+                    traceback.print_exc()
                     return {'errors': [str(e)]}, getattr(e, 'http_status', HTTP_500_INTERNAL_SERVER_ERROR)
                 obj.refresh_from_db()
 
@@ -352,6 +357,7 @@ class AlchemyJsonApiViewBuilder:
                 try:
                     obj = self._before_delete_callback(request, obj)
                 except Exception as e:
+                    traceback.print_exc()
                     return getattr(e, 'http_status', HTTP_500_INTERNAL_SERVER_ERROR)
             if obj:
                 obj.delete()
@@ -360,6 +366,7 @@ class AlchemyJsonApiViewBuilder:
                     try:
                         self._after_delete_callback(request, obj)
                     except Exception as e:
+                        traceback.print_exc()
                         return getattr(e, 'http_status', HTTP_500_INTERNAL_SERVER_ERROR)
             return HTTP_204_NO_CONTENT
 
